@@ -1,8 +1,13 @@
 # -*- coding: utf-8 -*-
 
+
 def atomic_push(redis_db, queue_id, item):
-    """ Push item to queue and get item position in
-    one atomic operation by using transaction. """
+    """
+    Push item to queue and get item position in
+    one atomic operation by using transaction.
+
+    The queue representation in Redis is a `list`.
+    """
     pipe = redis_db.pipeline()
     pipe.rpush(queue_id, item)
     pipe.llen(queue_id)
